This dataset is a portion of WMATA's bus GTFS, first published on Dec 14,
2025 and valid through June 13, 2026, accessed through TransitLand. The
dataset is intended to be used alongside the archived GTFS-realtime
feed provided in wmata_avl.
Format
wmata_gtfs
A tidytransit object (list) with 8 files.
- agency
The GTFS
agency.txtfile- routes
The GTFS
routes.txtfile- trips
The GTFS
trips.txtfile- stop_times
The GTFS
stop_times.txtfile- stops
The GTFS
stops.txtfile- shapes
The GTFS
shapes.txtfile- calendar
The GTFS
calendar.txtfile- calendar_dates
The GTFS
calendar_dates.txtfile
Details
This dataset has been filtered to three routes, with two directions for each:
D40: Georgia Ave
C53: U St/Congress Heights
D96: Mass Ave toBethesda
Examples
# Print the tidytransit summary
summary(wmata_gtfs)
#> tidygtfs object
#> files agency, routes, stop_times, trips, shapes, calendar, calendar_dates, stops
#> agency WMATA
#> service from 2025-12-14 to 2026-06-13
#> uses stop_times (no frequencies)
#> # routes 3
#> # trips 4167
#> # stop_ids 347
#> # stop_names 253
#> # shapes 15
# Filter by route & direction
my_route <- "D96"
my_dir <- 0
d96_gtfs <- filter_by_route(gtfs = wmata_gtfs,
route_ids = my_route,
dir_id = my_dir)
summary(d96_gtfs)
#> tidygtfs object
#> files agency, routes, stop_times, trips, shapes, calendar, calendar_dates, stops
#> agency WMATA
#> service from 2025-12-14 to 2026-06-13
#> uses stop_times (no frequencies)
#> # routes 1
#> # trips 320
#> # stop_ids 71
#> # stop_names 70
#> # shapes 2
# Extract route alignments
d96_shapes <- get_shape_geometry(gtfs = d96_gtfs)
print(d96_shapes)
#> Simple feature collection with 2 features and 1 field
#> Geometry type: MULTILINESTRING
#> Dimension: XY
#> Bounding box: xmin: -77.10056 ymin: 38.89265 xmax: -77.04168 ymax: 38.98564
#> Geodetic CRS: WGS 84
#> # A tibble: 2 × 2
#> shape_id geometry
#> <chr> <MULTILINESTRING [°]>
#> 1 D96:05 ((-77.04761 38.89588, -77.04774 38.89594, -77.04789 38.89601, -77.04…
#> 2 D96:06 ((-77.04344 38.90744, -77.04344 38.90725, -77.04354 38.90725, -77.04…
# Plot interactive Leaflet view
plot_interactive_gtfs(gtfs = wmata_gtfs,
color = "gtfs")